@@ -1,6 +1,7 @@
 
 from .column import Column, ForeignKey
 from .database import Database
+from .exc import BaserowOrmException, NoRowReturned
 from .mapping import DatabaseMapping
 from .model import Model
 
@@ -8,6 +9,8 @@ __all__ = [
   'Column',
   'ForeignKey',
   'Database',
+  'BaserowOrmException',
+  'NoRowReturned',
   'DatabaseMapping',
   'Model'
 ]
